@@ -1,8 +1,8 @@
 #!/usr/bin/python3
-'''
+"""
 Library for Casambi Cloud api.
 Request api_key at: https://developer.casambi.com/
-'''
+"""
 import uuid
 import json
 import logging
@@ -27,22 +27,17 @@ class ConfigException(Exception):
 
 
 class Casambi:
-    '''
+    """
     Casambi api object
-    '''
+    """
 
-    def __init__(self, *,
-                 api_key,
-                 email,
-                 user_password,
-                 network_password,
-                 wire_id=1):
+    def __init__(self, *, api_key, email, user_password, network_password, wire_id=1):
         self.sock = None
         self.web_sock = None
 
         self.connected = False
         self.network_id = None
-        self.user_session_id = None
+        self._session_id = None
 
         self.wire_id = wire_id
         self.api_key = api_key
@@ -51,12 +46,11 @@ class Casambi:
         self.network_password = network_password
 
     def create_user_session(self):
-        '''
+        """
         Function for creating a user session in Casambis cloud api
-        '''
-        url = 'https://door.casambi.com/v1/users/session/'
-        headers = {'Content-type': 'application/json',
-                   'X-Casambi-Key': self.api_key}
+        """
+        url = "https://door.casambi.com/v1/users/session/"
+        headers = {"Content-type": "application/json", "X-Casambi-Key": self.api_key}
 
         payload = {"email": self.email, "password": self.user_password}
 
@@ -72,24 +66,26 @@ class Casambi:
 
         data = response.json()
 
-        self.user_session_id = data['sessionId']
+        self._session_id = data["sessionId"]
 
-        return data['sessionId']
+        return data["sessionId"]
 
     def create_network_session(self):
-        '''
+        """
         Function for creating a network session in Casambis cloud api
-        '''
-        url = 'https://door.casambi.com/v1/networks/session/'
-        headers = {'X-Casambi-Key': self.api_key,
-                   'Content-type': 'application/json', }
+        """
+        url = "https://door.casambi.com/v1/networks/session/"
+        headers = {
+            "X-Casambi-Key": self.api_key,
+            "Content-type": "application/json",
+        }
 
         payload = {"email": self.email, "password": self.network_password}
 
         response = requests.post(url, json=payload, headers=headers)
 
         if response.status_code != 200:
-            reason = 'create_network_session: failed with'
+            reason = "create_network_session: failed with"
             reason += f"status_code: {response.status_code},"
             reason += f"response: {response.text}"
 
@@ -98,26 +94,29 @@ class Casambi:
         data = response.json()
 
         self.network_id = list(data.keys())[0]
+        self._session_id = data[self.network_id]["sessionId"]
 
         return data.keys()
 
     def get_network_information(self):
-        '''
+        """
         Function for getting the network information from Casambis cloud api
-        '''
+        """
         # GET https://door.casambi.com/v1/networks/{id}
 
         url = f"https://door.casambi.com/v1/networks/{self.network_id}"
 
-        headers = {'X-Casambi-Key': self.api_key, 'X-Casambi-Session':
-                   self.user_session_id, 'Content-type': 'application/json', }
+        headers = {
+            "X-Casambi-Key": self.api_key,
+            "X-Casambi-Session": self._session_id,
+            "Content-type": "application/json",
+        }
 
         response = requests.get(url, headers=headers)
 
         if response.status_code != 200:
             reason = "get_network_information: url: {}".format(url)
-            reason += "failed with status_code: {},".format(
-                response.status_code)
+            reason += "failed with status_code: {},".format(response.status_code)
             reason += "response: {}".format(response.text)
             raise CasambiApiException(reason)
 
@@ -131,23 +130,25 @@ class Casambi:
         return data
 
     def get_unit_state(self, *, unit_id):
-        '''
+        """
         Getter for getting the unit state from Casambis cloud api
-        '''
+        """
         # GET https://door.casambi.com/v1/networks/{id}
 
-        url = 'https://door.casambi.com/v1/networks/'
+        url = "https://door.casambi.com/v1/networks/"
         url += f"{self.network_id}/units/{unit_id}/state"
 
-        headers = {'X-Casambi-Key': self.api_key, 'X-Casambi-Session':
-                   self.user_session_id, 'Content-type': 'application/json', }
+        headers = {
+            "X-Casambi-Key": self.api_key,
+            "X-Casambi-Session": self._session_id,
+            "Content-type": "application/json",
+        }
 
         response = requests.get(url, headers=headers)
 
         if response.status_code != 200:
             reason = "get_unit_state: url: {}".format(url)
-            reason += "failed with status_code: {},".format(
-                response.status_code)
+            reason += "failed with status_code: {},".format(response.status_code)
             reason += "response: {}".format(response.text)
 
             raise CasambiApiException(reason)
@@ -160,7 +161,7 @@ class Casambi:
         return data
 
     def ws_open(self) -> bool:
-        '''
+        """
         openWireSucceed         API key authentication failed. Either given key
         was invalid or WebSocket functionality is not enabled for it.
 
@@ -178,22 +179,21 @@ class Casambi:
 
         invalidData	            Received data is invalid and cannot be
         processed, for example expected list of items is in wrong data format.
-        '''
-        url = 'wss://door.casambi.com/v1/bridge/'
+        """
+        url = "wss://door.casambi.com/v1/bridge/"
 
         reference = "{}".format(uuid.uuid1())
 
         message = {
             "method": "open",
             "id": self.network_id,
-            "session": self.user_session_id,
+            "session": self._session_id,
             "ref": reference,
             "wire": self.wire_id,  # wire id
-            "type": 1  # Client type, use value 1 (FRONTEND)
+            "type": 1,  # Client type, use value 1 (FRONTEND)
         }
 
-        self.web_sock = websocket.create_connection(
-            url, subprotocols=[self.api_key])
+        self.web_sock = websocket.create_connection(url, subprotocols=[self.api_key])
         self.web_sock.send(json.dumps(message))
 
         result = self.web_sock.recv()
@@ -211,19 +211,21 @@ class Casambi:
         #    reason += 'reason: "failed with to open wire!"'
         #    reason += "response: {}".format(data)
         #    raise CasambiApiException(reason)
-        if 'wireStatus' in data and data['wireStatus'] == 'openWireSucceed':
+        if "wireStatus" in data and data["wireStatus"] == "openWireSucceed":
             return True
 
-        if (('method' in data) and (data['method'] == 'peerChanged')) and \
-            (('wire' in data) and (data['wire'] == self.wire_id)) and \
-                (('online' in data) and data['online']):
+        if (
+            (("method" in data) and (data["method"] == "peerChanged"))
+            and (("wire" in data) and (data["wire"] == self.wire_id))
+            and (("online" in data) and data["online"])
+        ):
             return True
         return False
 
     def turn_unit_off(self, *, unit_id: int):
-        '''
+        """
         Function for turning a unit of using the websocket
-        '''
+        """
         # Unit_id needs to be an integer
         if isinstance(unit_id, int):
             pass
@@ -233,27 +235,28 @@ class Casambi:
             unit_id = int(unit_id)
         else:
             raise CasambiApiException(
-                "expected unit_id to be an integer, got: {}".format(unit_id))
+                "expected unit_id to be an integer, got: {}".format(unit_id)
+            )
 
         if not self.web_sock:
-            raise CasambiApiException('No websocket connection!')
+            raise CasambiApiException("No websocket connection!")
 
-        target_controls = {'Dimmer': {'value': 0}}
+        target_controls = {"Dimmer": {"value": 0}}
 
         message = {
             "wire": self.wire_id,
-            "method": 'controlUnit',
+            "method": "controlUnit",
             "id": unit_id,
-            "targetControls": target_controls
+            "targetControls": target_controls,
         }
 
         self.web_sock.send(json.dumps(message))
 
     def turn_unit_on(self, *, unit_id):
-        '''
+        """
         Response on ok:
         {'wire': 1, 'method': 'peerChanged', 'online': True}
-        '''
+        """
         # Unit_id needs to be an integer
         if isinstance(unit_id, int):
             pass
@@ -262,29 +265,29 @@ class Casambi:
         elif isinstance(unit_id, float):
             unit_id = int(unit_id)
         else:
-            reason = 'expected unit_id to be an integer,'
+            reason = "expected unit_id to be an integer,"
             reason += "got: {}".format(unit_id)
             raise CasambiApiException(reason)
 
         if not self.web_sock:
-            raise CasambiApiException('No websocket connection!')
+            raise CasambiApiException("No websocket connection!")
 
-        target_controls = {'Dimmer': {'value': 1}}
+        target_controls = {"Dimmer": {"value": 1}}
 
         message = {
             "wire": self.wire_id,
-            "method": 'controlUnit',
+            "method": "controlUnit",
             "id": unit_id,
-            "targetControls": target_controls
+            "targetControls": target_controls,
         }
 
         self.web_sock.send(json.dumps(message))
 
     def set_unit_target_controls(self, *, unit_id, target_controls):
-        '''
+        """
         Response on ok:
         {'wire': 1, 'method': 'peerChanged', 'online': True}
-        '''
+        """
         # Unit_id needs to be an integer
         if isinstance(unit_id, int):
             pass
@@ -294,25 +297,26 @@ class Casambi:
             unit_id = int(unit_id)
         else:
             raise CasambiApiException(
-                f"expected unit_id to be an integer, got: {unit_id}")
+                f"expected unit_id to be an integer, got: {unit_id}"
+            )
 
         if not self.web_sock:
-            raise CasambiApiException('No websocket connection!')
+            raise CasambiApiException("No websocket connection!")
 
         message = {
             "wire": self.wire_id,
-            "method": 'controlUnit',
+            "method": "controlUnit",
             "id": unit_id,
-            "targetControls": target_controls
+            "targetControls": target_controls,
         }
 
         self.web_sock.send(json.dumps(message))
 
     def set_unit_value(self, *, unit_id: int, value):
-        '''
+        """
         Response on ok:
         {'wire': 1, 'method': 'peerChanged', 'online': True}
-        '''
+        """
         # Unit_id needs to be an integer
         if isinstance(unit_id, int):
             pass
@@ -322,31 +326,32 @@ class Casambi:
             unit_id = int(unit_id)
         else:
             raise CasambiApiException(
-                f"expected unit_id to be an integer, got: {unit_id}")
+                f"expected unit_id to be an integer, got: {unit_id}"
+            )
 
-        if not(value >= 0 and value <= 1):
-            raise CasambiApiException('value needs to be between 0 and 1')
+        if not (value >= 0 and value <= 1):
+            raise CasambiApiException("value needs to be between 0 and 1")
 
         if not self.web_sock:
-            raise CasambiApiException('No websocket connection!')
+            raise CasambiApiException("No websocket connection!")
 
-        target_controls = {'Dimmer': {'value': value}}
+        target_controls = {"Dimmer": {"value": value}}
 
         message = {
             "wire": self.wire_id,
-            "method": 'controlUnit',
+            "method": "controlUnit",
             "id": unit_id,
-            "targetControls": target_controls
+            "targetControls": target_controls,
         }
 
         self.web_sock.send(json.dumps(message))
 
-    def set_unit_rgbw_color(self, *,
-                                unit_id: int,
-                                color_value: Tuple[int, int, int, int]):
-        '''
+    def set_unit_rgbw_color(
+        self, *, unit_id: int, color_value: Tuple[int, int, int, int]
+    ):
+        """
         Setter for RGB color
-        '''
+        """
         target_controls = None
         (red, green, blue, white) = color_value
 
@@ -358,35 +363,35 @@ class Casambi:
             unit_id = int(unit_id)
         else:
             raise CasambiApiException(
-                "expected unit_id to be an integer, got: {}".format(unit_id))
+                "expected unit_id to be an integer, got: {}".format(unit_id)
+            )
 
         if not self.web_sock:
-            raise CasambiApiException('No websocket connection!')
+            raise CasambiApiException("No websocket connection!")
 
         white_value = white / 255.0
         # 'name': 'white', 'type': 'White', 'value': 0.0
         target_controls = {
-            'RGB': {'rgb': f"rgb({red}, {green}, {blue})"},
-            'Colorsource': {'source': 'RGB'},
-            'White': {'value': white_value},
+            "RGB": {"rgb": f"rgb({red}, {green}, {blue})"},
+            "Colorsource": {"source": "RGB"},
+            "White": {"value": white_value},
         }
 
         message = {
             "wire": self.wire_id,
-            "method": 'controlUnit',
+            "method": "controlUnit",
             "id": unit_id,
-            "targetControls": target_controls
+            "targetControls": target_controls,
         }
 
         self.web_sock.send(json.dumps(message))
 
-    def set_unit_rgb_color(self, *,
-                                unit_id: int,
-                                color_value: Tuple[int, int, int],
-                                send_rgb_format=False):
-        '''
+    def set_unit_rgb_color(
+        self, *, unit_id: int, color_value: Tuple[int, int, int], send_rgb_format=False
+    ):
+        """
         Setter for RGB color
-        '''
+        """
         target_controls = None
         (red, green, blue) = color_value
         (hue, sat, value) = rgb_to_hsv(red, green, blue)
@@ -399,69 +404,66 @@ class Casambi:
             unit_id = int(unit_id)
         else:
             raise CasambiApiException(
-                "expected unit_id to be an integer, got: {}".format(unit_id))
+                "expected unit_id to be an integer, got: {}".format(unit_id)
+            )
 
         if not self.web_sock:
-            raise CasambiApiException('No websocket connection!')
+            raise CasambiApiException("No websocket connection!")
 
         if not send_rgb_format:
             target_controls = {
-                'RGB': {'hue': round(hue, 1), 'sat': round(sat, 1)},
-                'Colorsource': {'source': 'RGB'}
+                "RGB": {"hue": round(hue, 1), "sat": round(sat, 1)},
+                "Colorsource": {"source": "RGB"},
             }
         else:
             target_controls = {
-                'RGB': {'rgb': f"rgb({red}, {green}, {blue})"},
-                'Colorsource': {'source': 'RGB'}
+                "RGB": {"rgb": f"rgb({red}, {green}, {blue})"},
+                "Colorsource": {"source": "RGB"},
             }
 
         message = {
             "wire": self.wire_id,
-            "method": 'controlUnit',
+            "method": "controlUnit",
             "id": unit_id,
-            "targetControls": target_controls
+            "targetControls": target_controls,
         }
 
         self.web_sock.send(json.dumps(message))
 
-    def set_unit_color_temperature(self, *,
-                                   unit_id: int,
-                                   value: int,
-                                   source="TW"):
-        '''
+    def set_unit_color_temperature(self, *, unit_id: int, value: int, source="TW"):
+        """
         Setter for unit color temperature (kelvin)
-        '''
+        """
         target_value = value
-        if source == 'mired':
+        if source == "mired":
             # Convert to Kelvin
             target_value = round(1000000 / value)
 
         # Convert to nerest 50 in kelvin, like the gui is doing
         if target_value % 50 != 0:
-            target_value = int(target_value/50)*50+50
+            target_value = int(target_value / 50) * 50 + 50
 
-            dbg_msg = 'set_unit_color_temperature '
+            dbg_msg = "set_unit_color_temperature "
             dbg_msg += f"converting target value to {target_value}"
-            dbg_msg += ' (nearest 50 kelvin like GUI)'
+            dbg_msg += " (nearest 50 kelvin like GUI)"
             _LOGGER.debug(dbg_msg)
 
         # Get min and max temperature color in kelvin
-        (cct_min, cct_max, _) = \
-            self.get_supported_color_temperature(unit_id=unit_id)
+        (cct_min, cct_max, _) = self.get_supported_color_temperature(unit_id=unit_id)
         if target_value < cct_min:
-            dbg_msg = 'set_unit_color_temperature '
+            dbg_msg = "set_unit_color_temperature "
             dbg_msg += f"target_value: {target_value}"
-            dbg_msg += ' smaller than min supported temperature,'
-            dbg_msg += ' setting to min supported color temperature:'
+            dbg_msg += " smaller than min supported temperature,"
+            dbg_msg += " setting to min supported color temperature:"
             dbg_msg += f" {cct_min}"
             _LOGGER.debug(dbg_msg)
 
             target_value = cct_min
         elif target_value > cct_max:
-            dbg_msg = 'set_unit_color_temperature '
+            dbg_msg = "set_unit_color_temperature "
             dbg_msg += f"target_value: {target_value}"
-            dbg_msg += ' larger than max supported temperature,'
-            dbg_msg += ' setting to max supported color temperature:'
+            dbg_msg += " larger than max supported temperature,"
+            dbg_msg += " setting to max supported color temperature:"
             dbg_msg += f" {cct_max}"
             _LOGGER.debug(dbg_msg)
 
@@ -476,58 +478,59 @@ class Casambi:
             unit_id = int(unit_id)
         else:
             raise CasambiApiException(
-                f"expected unit_id to be an integer, got: {unit_id}")
+                f"expected unit_id to be an integer, got: {unit_id}"
+            )
 
         if not self.web_sock:
-            raise CasambiApiException('No websocket connection!')
+            raise CasambiApiException("No websocket connection!")
 
         target_controls = {
-            'ColorTemperature': {'value': target_value},
-            'Colorsource': {'source': 'TW'}
+            "ColorTemperature": {"value": target_value},
+            "Colorsource": {"source": "TW"},
         }
 
         message = {
             "wire": self.wire_id,
-            "method": 'controlUnit',
+            "method": "controlUnit",
             "id": unit_id,
-            "targetControls": target_controls
+            "targetControls": target_controls,
         }
 
         self.web_sock.send(json.dumps(message))
 
-    def get_supported_color_temperature(self, *, unit_id: int) -> \
-            Tuple[int, int, float]:
-        '''
+    def get_supported_color_temperature(
+        self, *, unit_id: int
+    ) -> Tuple[int, int, float]:
+        """
         Return the supported color temperatures
 
         Returns (0, 0, 0) if nothing is supported
-        '''
+        """
         cct_min = 0
         cct_max = 0
         current = 0
 
         data = self.get_unit_state(unit_id=unit_id)
 
-        if 'controls' not in data:
+        if "controls" not in data:
             return (cct_min, cct_max, current)
 
-        for control in data['controls']:
+        for control in data["controls"]:
             if isinstance(control, list):
                 for inner_control in control:
-                    if 'type' in inner_control and \
-                            inner_control['type'] == 'CCT':
-                        cct_min = inner_control['min']
-                        cct_max = inner_control['max']
-                        current = inner_control['value']
-            if 'type' in control and control['type'] == 'CCT':
-                cct_min = control['min']
-                cct_max = control['max']
-                current = control['value']
+                    if "type" in inner_control and inner_control["type"] == "CCT":
+                        cct_min = inner_control["min"]
+                        cct_max = inner_control["max"]
+                        current = inner_control["value"]
+            if "type" in control and control["type"] == "CCT":
+                cct_min = control["min"]
+                cct_max = control["max"]
+                current = control["value"]
 
         return (cct_min, cct_max, current)
 
     def unit_supports_rgbw(self, *, unit_id: int) -> bool:
-        '''
+        """
         Returns true if unit supports color temperature
 
         {
@@ -554,27 +557,25 @@ class Casambi:
             'status': 'ok',
             'type': 'Luminaire'}
 
-        '''
+        """
 
         data = self.get_unit_state(unit_id=unit_id)
         color = False
         white = False
 
-        if 'controls' not in data:
+        if "controls" not in data:
             return False
 
-        for control in data['controls']:
+        for control in data["controls"]:
             if isinstance(control, list):
                 for inner_control in control:
-                    if 'type' in inner_control and \
-                            inner_control['type'] == 'Color':
+                    if "type" in inner_control and inner_control["type"] == "Color":
                         color = True
-                    elif 'type' in inner_control and \
-                            inner_control['type'] == 'White':
+                    elif "type" in inner_control and inner_control["type"] == "White":
                         white = True
-            if 'type' in control and control['type'] == 'Color':
+            if "type" in control and control["type"] == "Color":
                 color = True
-            elif 'type' in control and control['type'] == 'White':
+            elif "type" in control and control["type"] == "White":
                 white = True
 
         if color and white:
@@ -582,7 +583,7 @@ class Casambi:
         return False
 
     def unit_supports_rgb(self, *, unit_id: int) -> bool:
-        '''
+        """
         Returns true if unit supports color temperature
 
         {
@@ -609,26 +610,24 @@ class Casambi:
             'status': 'ok',
             'type': 'Luminaire'}
 
-        '''
+        """
 
         data = self.get_unit_state(unit_id=unit_id)
 
-        if 'controls' not in data:
+        if "controls" not in data:
             return False
 
-        for control in data['controls']:
+        for control in data["controls"]:
             if isinstance(control, list):
                 for inner_control in control:
-                    if 'type' in inner_control and \
-                            inner_control['type'] == 'Color':
+                    if "type" in inner_control and inner_control["type"] == "Color":
                         return True
-            if 'type' in control and control['type'] == 'Color':
+            if "type" in control and control["type"] == "Color":
                 return True
         return False
 
-    def unit_supports_color_temperature(self, *,
-                                        unit_id: int) -> bool:
-        '''
+    def unit_supports_color_temperature(self, *, unit_id: int) -> bool:
+        """
         Returns true if unit supports color temperature
 
         {
@@ -656,28 +655,27 @@ class Casambi:
             'type': 'Luminaire'
         }
 
-        '''
+        """
 
         data = self.get_unit_state(unit_id=unit_id)
 
-        if 'controls' not in data:
+        if "controls" not in data:
             return False
 
-        for control in data['controls']:
+        for control in data["controls"]:
             if isinstance(control, list):
                 for inner_control in control:
-                    if 'type' in inner_control and \
-                            inner_control['type'] == 'CCT':
+                    if "type" in inner_control and inner_control["type"] == "CCT":
                         return True
-            if 'type' in control and control['type'] == 'CCT':
+            if "type" in control and control["type"] == "CCT":
                 return True
         return False
 
     def turn_scene_off(self, *, scene_id: int):
-        '''
+        """
         Response on ok:
         {'wire': 1, 'method': 'peerChanged', 'online': True}
-        '''
+        """
         # Unit_id needs to be an integer
         if isinstance(scene_id, int):
             pass
@@ -687,27 +685,28 @@ class Casambi:
             scene_id = int(scene_id)
         else:
             raise CasambiApiException(
-                f"expected scene_id to be an integer, got: {scene_id}")
+                f"expected scene_id to be an integer, got: {scene_id}"
+            )
 
         if not self.web_sock:
-            raise CasambiApiException('No websocket connection!')
+            raise CasambiApiException("No websocket connection!")
 
         value = 0
 
         message = {
             "wire": self.wire_id,
-            "method": 'controlScene',
+            "method": "controlScene",
             "id": scene_id,
-            "level": value
+            "level": value,
         }
 
         self.web_sock.send(json.dumps(message))
 
     def turn_scene_on(self, *, scene_id):
-        '''
+        """
         Response on ok:
         {'wire': 1, 'method': 'peerChanged', 'online': True}
-        '''
+        """
         # Unit_id needs to be an integer
         if isinstance(scene_id, int):
             pass
@@ -717,38 +716,42 @@ class Casambi:
             scene_id = int(scene_id)
         else:
             raise CasambiApiException(
-                f"expected scene_id to be an integer, got: {scene_id}")
+                f"expected scene_id to be an integer, got: {scene_id}"
+            )
 
         if not self.web_sock:
-            raise CasambiApiException('No websocket connection!')
+            raise CasambiApiException("No websocket connection!")
 
         value = 1
 
         message = {
             "wire": self.wire_id,
-            "method": 'controlScene',
+            "method": "controlScene",
             "id": scene_id,
-            "level": value
+            "level": value,
         }
 
         self.web_sock.send(json.dumps(message))
 
     def get_unit_list(self):
-        '''
+        """
         Getter for unit lists
-        '''
-        url = 'https://door.casambi.com/v1/networks/'
+        """
+        url = "https://door.casambi.com/v1/networks/"
         url += f"{self.network_id}/units"
 
-        headers = {'X-Casambi-Key': self.api_key, 'X-Casambi-Session':
-                   self.user_session_id, 'Content-type': 'application/json', }
+        headers = {
+            "X-Casambi-Key": self.api_key,
+            "X-Casambi-Session": self._session_id,
+            "Content-type": "application/json",
+        }
 
         response = requests.get(url, headers=headers)
 
         if response.status_code != 200:
             reason = f"get_network_unit_list: headers: {headers},"
             reason += 'message: "Got a invalid status_code",'
-            reason += f"status_code: {response.status_cod},"
+            reason += f"status_code: {response.status_code},"
             reason += f"response: {response.text}"
 
             raise CasambiApiException(reason)
@@ -763,14 +766,17 @@ class Casambi:
         return data
 
     def get_scenes_list(self):
-        '''
+        """
         Getter for Scenes list
-        '''
-        url = 'https://door.casambi.com/v1/networks/'
+        """
+        url = "https://door.casambi.com/v1/networks/"
         url += f"{self.network_id}/scenes"
 
-        headers = {'X-Casambi-Key': self.api_key, 'X-Casambi-Session':
-                   self.user_session_id, 'Content-type': 'application/json', }
+        headers = {
+            "X-Casambi-Key": self.api_key,
+            "X-Casambi-Session": self._session_id,
+            "Content-type": "application/json",
+        }
 
         response = requests.get(url, headers=headers)
 
@@ -791,14 +797,17 @@ class Casambi:
         return data
 
     def get_fixture_information(self, *, unit_id: int):
-        '''
+        """
         GET https://door.casambi.com/v1/fixtures/{id}
-        '''
+        """
 
         url = f"https://door.casambi.com/v1/fixtures/{unit_id}"
 
-        headers = {'X-Casambi-Key': self.api_key, 'X-Casambi-Session':
-                   self.user_session_id, 'Content-type': 'application/json', }
+        headers = {
+            "X-Casambi-Key": self.api_key,
+            "X-Casambi-Session": self._session_id,
+            "Content-type": "application/json",
+        }
 
         response = requests.get(url, headers=headers)
 
@@ -819,13 +828,16 @@ class Casambi:
         return data
 
     def get_network_state(self):
-        '''
+        """
         Getter for network state
-        '''
+        """
         url = f"https://door.casambi.com/v1/networks/{self.network_id}/state"
 
-        headers = {'X-Casambi-Key': self.api_key, 'X-Casambi-Session':
-                   self.user_session_id, 'Content-type': 'application/json', }
+        headers = {
+            "X-Casambi-Key": self.api_key,
+            "X-Casambi-Session": self._session_id,
+            "Content-type": "application/json",
+        }
 
         response = requests.get(url, headers=headers)
 
@@ -845,20 +857,20 @@ class Casambi:
 
         return data
 
-    def get_network_datapoints(self, *,
-                               from_time=None,
-                               to_time=None,
-                               sensor_type=0):
-        '''
+    def get_network_datapoints(self, *, from_time=None, to_time=None, sensor_type=0):
+        """
         sensorType: [0 = Casambi | 1 = Vendor]
         from: yyyyMMdd[hh[mm[ss]]]
         to: yyyyMMdd[hh[mm[ss]]]
-        '''
-        headers = {'X-Casambi-Key': self.api_key, 'X-Casambi-Session':
-                   self.user_session_id, 'Content-type': 'application/json', }
+        """
+        headers = {
+            "X-Casambi-Key": self.api_key,
+            "X-Casambi-Session": self._session_id,
+            "Content-type": "application/json",
+        }
 
         if sensor_type not in [0, 1]:
-            raise CasambiApiException('invalid sentor_type')
+            raise CasambiApiException("invalid sentor_type")
 
         now = datetime.datetime.now()
 
@@ -866,12 +878,18 @@ class Casambi:
             to_time = now.strftime("%Y%m%d%H%M")
 
         if not from_time:
-            from_time = (now - datetime.timedelta(days=7)
-                         ).strftime("%Y%m%d%H%M")
+            from_time = (now - datetime.timedelta(days=7)).strftime("%Y%m%d%H%M")
 
-        url = 'https://door.casambi.com/v1/networks/' + \
-            str(self.network_id) + '/datapoints?sensorType=' + \
-            str(sensor_type) + '&from=' + from_time + '&to=' + to_time
+        url = (
+            "https://door.casambi.com/v1/networks/"
+            + str(self.network_id)
+            + "/datapoints?sensorType="
+            + str(sensor_type)
+            + "&from="
+            + from_time
+            + "&to="
+            + to_time
+        )
 
         response = requests.get(url, headers=headers)
 
@@ -893,12 +911,12 @@ class Casambi:
         return data
 
     def ws_recieve_message(self):
-        '''
+        """
         Response on success?
         {'wire': 1, 'method': 'peerChanged', 'online': True}
-        '''
+        """
         if not self.web_sock:
-            raise CasambiApiException('No websocket connection!')
+            raise CasambiApiException("No websocket connection!")
 
         result = self.web_sock.recv()
 
@@ -907,14 +925,14 @@ class Casambi:
         return data
 
     def ws_recieve_messages(self):
-        '''
+        """
         Response on success?
         {'wire': 1, 'method': 'peerChanged', 'online': True}
-        '''
+        """
         messages = []
 
         if not self.web_sock:
-            raise CasambiApiException('No websocket connection!')
+            raise CasambiApiException("No websocket connection!")
 
         self.web_sock.settimeout(0.1)
 
@@ -933,17 +951,14 @@ class Casambi:
         return messages
 
     def ws_close(self):
-        '''
+        """
         Response on success?
         {'wire': 1, 'method': 'peerChanged', 'online': True}
-        '''
+        """
 
         if not self.web_sock:
-            raise CasambiApiException('No websocket connection!')
+            raise CasambiApiException("No websocket connection!")
 
-        message = {
-            "method": "close",
-            "wire": self.wire_id
-        }
+        message = {"method": "close", "wire": self.wire_id}
 
         self.web_sock.send(json.dumps(message))
